#define ONFRONTCONNECTED 0
#define ONFRONTDISCONNECTED 1
#define ONHEARTBEATWARNING 2
#define ONRSPAUTHENTICATE 3
#define ONRSPUSERLOGIN 4
#define ONRSPUSERLOGOUT 5
#define ONRSPUSERPASSWORDUPDATE 6
#define ONRSPTRADINGACCOUNTPASSWORDUPDATE 7
#define ONRSPORDERINSERT 8
#define ONRSPPARKEDORDERINSERT 9
#define ONRSPPARKEDORDERACTION 10
#define ONRSPORDERACTION 11
#define ONRSPQUERYMAXORDERVOLUME 12
#define ONRSPSETTLEMENTINFOCONFIRM 13
#define ONRSPREMOVEPARKEDORDER 14
#define ONRSPREMOVEPARKEDORDERACTION 15
#define ONRSPEXECORDERINSERT 16
#define ONRSPEXECORDERACTION 17
#define ONRSPFORQUOTEINSERT 18
#define ONRSPQUOTEINSERT 19
#define ONRSPQUOTEACTION 20
#define ONRSPLOCKINSERT 21
#define ONRSPBATCHORDERACTION 22
#define ONRSPCOMBACTIONINSERT 23
#define ONRSPQRYORDER 24
#define ONRSPQRYTRADE 25
#define ONRSPQRYINVESTORPOSITION 26
#define ONRSPQRYTRADINGACCOUNT 27
#define ONRSPQRYINVESTOR 28
#define ONRSPQRYTRADINGCODE 29
#define ONRSPQRYINSTRUMENTMARGINRATE 30
#define ONRSPQRYINSTRUMENTCOMMISSIONRATE 31
#define ONRSPQRYEXCHANGE 32
#define ONRSPQRYPRODUCT 33
#define ONRSPQRYINSTRUMENT 34
#define ONRSPQRYDEPTHMARKETDATA 35
#define ONRSPQRYSETTLEMENTINFO 36
#define ONRSPQRYTRANSFERBANK 37
#define ONRSPQRYINVESTORPOSITIONDETAIL 38
#define ONRSPQRYNOTICE 39
#define ONRSPQRYSETTLEMENTINFOCONFIRM 40
#define ONRSPQRYINVESTORPOSITIONCOMBINEDETAIL 41
#define ONRSPQRYCFMMCTRADINGACCOUNTKEY 42
#define ONRSPQRYEWARRANTOFFSET 43
#define ONRSPQRYINVESTORPRODUCTGROUPMARGIN 44
#define ONRSPQRYEXCHANGEMARGINRATE 45
#define ONRSPQRYEXCHANGEMARGINRATEADJUST 46
#define ONRSPQRYEXCHANGERATE 47
#define ONRSPQRYSECAGENTACIDMAP 48
#define ONRSPQRYPRODUCTEXCHRATE 49
#define ONRSPQRYPRODUCTGROUP 50
#define ONRSPQRYMMINSTRUMENTCOMMISSIONRATE 51
#define ONRSPQRYMMOPTIONINSTRCOMMRATE 52
#define ONRSPQRYINSTRUMENTORDERCOMMRATE 53
#define ONRSPQRYOPTIONINSTRTRADECOST 54
#define ONRSPQRYOPTIONINSTRCOMMRATE 55
#define ONRSPQRYEXECORDER 56
#define ONRSPQRYFORQUOTE 57
#define ONRSPQRYQUOTE 58
#define ONRSPQRYLOCK 59
#define ONRSPQRYLOCKPOSITION 60
#define ONRSPQRYETFOPTIONINSTRCOMMRATE 61
#define ONRSPQRYLIMITPOSI 62
#define ONRSPQRYINVESTORLEVEL 63
#define ONRSPQRYEXECFREEZE 64
#define ONRSPQRYLIMITAMOUNT 65
#define ONRSPQRYCOMBINSTRUMENTGUARD 66
#define ONRSPQRYCOMBACTION 67
#define ONRSPQRYTRANSFERSERIAL 68
#define ONRSPQRYACCOUNTREGISTER 69
#define ONRSPERROR 70
#define ONRTNORDER 71
#define ONRTNTRADE 72
#define ONERRRTNORDERINSERT 73
#define ONERRRTNORDERACTION 74
#define ONRTNINSTRUMENTSTATUS 75
#define ONRTNBULLETIN 76
#define ONRTNTRADINGNOTICE 77
#define ONRTNERRORCONDITIONALORDER 78
#define ONRTNEXECORDER 79
#define ONERRRTNEXECORDERINSERT 80
#define ONERRRTNEXECORDERACTION 81
#define ONERRRTNFORQUOTEINSERT 82
#define ONRTNQUOTE 83
#define ONERRRTNQUOTEINSERT 84
#define ONERRRTNQUOTEACTION 85
#define ONRTNFORQUOTERSP 86
#define ONRTNCFMMCTRADINGACCOUNTTOKEN 87
#define ONRTNLOCK 88
#define ONERRRTNLOCKINSERT 89
#define ONERRRTNBATCHORDERACTION 90
#define ONRTNCOMBACTION 91
#define ONERRRTNCOMBACTIONINSERT 92
#define ONRSPQRYCONTRACTBANK 93
#define ONRSPQRYPARKEDORDER 94
#define ONRSPQRYPARKEDORDERACTION 95
#define ONRSPQRYTRADINGNOTICE 96
#define ONRSPQRYBROKERTRADINGPARAMS 97
#define ONRSPQRYBROKERTRADINGALGOS 98
#define ONRSPQUERYCFMMCTRADINGACCOUNTTOKEN 99
#define ONRTNFROMBANKTOFUTUREBYBANK 100
#define ONRTNFROMFUTURETOBANKBYBANK 101
#define ONRTNREPEALFROMBANKTOFUTUREBYBANK 102
#define ONRTNREPEALFROMFUTURETOBANKBYBANK 103
#define ONRTNFROMBANKTOFUTUREBYFUTURE 104
#define ONRTNFROMFUTURETOBANKBYFUTURE 105
#define ONRTNREPEALFROMBANKTOFUTUREBYFUTUREMANUAL 106
#define ONRTNREPEALFROMFUTURETOBANKBYFUTUREMANUAL 107
#define ONRTNQUERYBANKBALANCEBYFUTURE 108
#define ONERRRTNBANKTOFUTUREBYFUTURE 109
#define ONERRRTNFUTURETOBANKBYFUTURE 110
#define ONERRRTNREPEALBANKTOFUTUREBYFUTUREMANUAL 111
#define ONERRRTNREPEALFUTURETOBANKBYFUTUREMANUAL 112
#define ONERRRTNQUERYBANKBALANCEBYFUTURE 113
#define ONRTNREPEALFROMBANKTOFUTUREBYFUTURE 114
#define ONRTNREPEALFROMFUTURETOBANKBYFUTURE 115
#define ONRSPFROMBANKTOFUTUREBYFUTURE 116
#define ONRSPFROMFUTURETOBANKBYFUTURE 117
#define ONRSPQUERYBANKACCOUNTMONEYBYFUTURE 118
#define ONRTNOPENACCOUNTBYBANK 119
#define ONRTNCANCELACCOUNTBYBANK 120
#define ONRTNCHANGEACCOUNTBYBANK 121
#define ONRTNRESOPENACCCONFIRMTPDBYBANK 122
#define ONRSPRESERVEOPENACCOUNTTPDBYFUTURE 123
#define ONRSPSECURITIESDEPOSITINTERESTBYFUTURE 124
#define ONRSPDAYENDFILEREADYBYFUTURE 125
#define ONRSPEXECCOMBINEORDERINSERT 126
#define ONRSPEXECCOMBINEORDERACTION 127
#define ONRSPQRYEXECCOMBINEORDER 128
#define ONERRRTNEXECCOMBINEORDERACTION 129
#define ONERRRTNEXECCOMBINEORDERINSERT 130
#define ONRTNEXECCOMBINEORDER 131
#define ONRSPINTERNALTRANSFER 132
#define ONRTNINTERNALTRANSFER 133
#define ONRSPQRYINTERNALTRANSFER 134
#define ONRSPQRYFUTURETRADINGACCOUNT 135
